==> activity-custom-center-api-0.2.80-20200915.091656-3-sources.jar: cn/com/duiba/activity/custom/center/api/dto/boc/UserWhiteListDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.boc;

import java.io.Serializable;
import java.util.Date;

/**
 * @author xujing
 * @date 2020/3/12
 */
public class UserWhiteListDto implements Serializable {
    private static final long serialVersionUID = 7331305557764563030L;


    private Long id;

    private Date gmtCreate;

    private Date gmtModify;

    private Long appId;

    /**
     * 业务类型 1手机号
     */
    private Integer relType;

    private String relValue;

    /**
     * 是否删除 0未删除 1已删除
     */
    private Boolean deleted;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModify() {
        return gmtModify;
    }

    public void setGmtModify(Date gmtModify) {
        this.gmtModify = gmtModify;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getRelType() {
        return relType;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }

    public String getRelValue() {
        return relValue;
    }

    public void setRelValue(String relValue) {
        this.relValue = relValue;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }
}

==> activity-custom-center-api-0.2.93-sources.jar: cn/com/duiba/activity/custom/center/api/dto/boc/UserWhiteListDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.boc;

import java.io.Serializable;
import java.util.Date;

/**
 * @author xujing
 * @date 2020/3/12
 */
public class UserWhiteListDto implements Serializable {
    private static final long serialVersionUID = 7331305557764563030L;


    private Long id;

    private Date gmtCreate;

    private Date gmtModify;

    private Long appId;

    /**
     * 业务类型 1手机号
     */
    private Integer relType;

    private String relValue;

    /**
     * 是否删除 0未删除 1已删除
     */
    private Boolean deleted;

    /**
     * 当月导入积分
     */
    private Long userPoint;

    /**
     * 当月导入等级
     */
    private String userLevel;

    /**
     * 所属银行
     */
    private String branch;
    /**
     * excel导入时间
     */
    private Date importDate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModify() {
        return gmtModify;
    }

    public void setGmtModify(Date gmtModify) {
        this.gmtModify = gmtModify;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getRelType() {
        return relType;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }

    public String getRelValue() {
        return relValue;
    }

    public void setRelValue(String relValue) {
        this.relValue = relValue;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Long getUserPoint() {
        return userPoint;
    }

    public void setUserPoint(Long userPoint) {
        this.userPoint = userPoint;
    }

    public String getUserLevel() {
        return userLevel;
    }

    public void setUserLevel(String userLevel) {
        this.userLevel = userLevel;
    }

    public String getBranch() {
        return branch;
    }

    public void setBranch(String branch) {
        this.branch = branch;
    }

    public Date getImportDate() {
        return importDate;
    }

    public void setImportDate(Date importDate) {
        this.importDate = importDate;
    }
}
